Summary: System administration tools for monitoring users' disk usage
Name:    quota
Version: 4.09
Release: 2%{?dist}
License: GPLv2 and GPLv2+
URL: http://sourceforge.net/projects/linuxquota/
Source0: http://downloads.sourceforge.net/linuxquota/%{name}-%{version}.tar.gz
Source1: quota_nld.service
Source2: quota_nld.sysconfig
Source3: rpc-rquotad.service
Source4: rpc-rquotad.sysconfig
Patch0001: backport-warnquota-configuration-tunes.patch
Patch0002: quota-4.03-Validate-upper-bound-of-RPC-port.patch

BuildRequires:  autoconf, automake, gcc, bash
BuildRequires:  coreutils, e2fsprogs-devel, gettext-devel, openldap-devel
BuildRequires:  pkgconfig(com_err), pkgconfig(ext2fs), pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libnl-3.0) >= 3.1, pkgconfig(libnl-genl-3.0), rpcgen, pkgconfig(libtirpc)
Provides: %{name}-nls = %{version}-%{release}
Provides: %{name}-doc = %{version}-%{release}

%description
Quota subsystem allows system administrator to set limits on used space and
number of used inodes (inode is a filesystem structure which is associated
which each file or directory) for users and/or groups.


%package nld
Summary:    quota_nld daemon
Requires:   quota-nls = %{version}-%{release}, systemd

%description nld
quota_nld listens on netlink socket and processes received quota warnings.
By default quota_nld forwards warning messages to both the system's DBUS 
(so that the desktop manager can display a dialog) and the last-accessed
terminal of the user to whom each warning is directed.

%package rpc
Summary:    RPC quota daemon
License:    LGPLv2+ and GPLv2 and GPLv2+
Requires:   quota-nls = %{version}-%{release}
Requires:   rpcbind, systemd

%description rpc
This package provides an rpc server which returns quotas for a user of a local
filesystem which is mounted by a remote machine over the NFS.  It also allows
setting of quotas on NFS mounted filesystem (if configured during compilation
and allowed by a command line option -S).  The results are used by quota to
display user quotas for remote filesystems and by edquota(8) to set quotas on
remote filesystems.

%package warnquota
Summary:    Send e-mail to users over quota
Requires:   quota-nls = %{version}-%{release}

%description warnquota
warnquota checks the disk quota for specified local filesystems (or for each
local filesystem if none specified) and mails a warning message to those users
who have reached their softlimit.  It is typically run via cron(8).

%package devel
Summary:    Development files for quota RPC
Requires:   libtirpc-devel

%description devel
This package provides header files for developers who use disk quotas
on remote machines.

%prep
%autosetup -p1
autoreconf -f

%build
%configure \
    --enable-ldapmail=yes \
    --disable-libwrap \
    --enable-netlink=yes \
    --enable-nls \
    --with-pid-dir=/run \
    --disable-rpath \
    --enable-rpc=yes \
    --enable-rpcsetquota=yes \
    --disable-silent-rules \
    --disable-xfs-roothack
%{make_build}


%install
%{make_install}
rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}

install -Dp -m644 %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/quota_nld.service
install -Dp -m644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/quota_nld
install -Dp -m644 %{SOURCE3} $RPM_BUILD_ROOT%{_unitdir}/rpc-rquotad.service
install -Dp -m644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/rpc-rquotad

%find_lang %{name}

%check
make check

%post nld
%systemd_post quota_nld.service

%preun nld
%systemd_preun quota_nld.service

%postun nld
%systemd_postun_with_restart quota_nld.service

%post rpc
%systemd_post rpc-rquotad.service

%preun rpc
%systemd_preun rpc-rquotad.service

%postun rpc
%systemd_postun_with_restart rpc-rquotad.service


%files -f %{name}.lang
%license COPYING
%doc Changelog doc/* ldap-scripts
%{_sbindir}/convertquota
%{_sbindir}/edquota
%{_sbindir}/quotacheck
%{_sbindir}/quotaoff
%{_sbindir}/quotaon
%{_sbindir}/quotastats
%{_sbindir}/repquota
%{_sbindir}/setquota
%{_sbindir}/xqmstats
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%exclude %{_mandir}/man8/quota_nld.8*
%exclude %{_mandir}/man8/rpc.rquotad.8*
%exclude %{_mandir}/man8/warnquota.8*

%files nld
%{_sbindir}/quota_nld
%config(noreplace) %{_sysconfdir}/sysconfig/quota_nld
%{_unitdir}/quota_nld.service
%{_mandir}/man8/quota_nld.8*

%files rpc
%{_sbindir}/rpc.rquotad
%config(noreplace) %{_sysconfdir}/sysconfig/rpc-rquotad
%{_unitdir}/rpc-rquotad.service
%{_mandir}/man8/rpc.rquotad.8*

%files warnquota
%doc README.ldap-support README.mailserver
%{_sbindir}/warnquota
%config(noreplace) %{_sysconfdir}/quotagrpadmins
%config(noreplace) %{_sysconfdir}/quotatab
%config(noreplace) %{_sysconfdir}/warnquota.conf
%{_mandir}/man5/*
%{_mandir}/man8/warnquota.8*

%files devel
%dir %{_includedir}/rpcsvc
%{_includedir}/rpcsvc/*
%{_mandir}/man3/*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.09-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Aug 21 2023 Shuo Wang <abushwang@tencent.com> - 4.09-1
- update to 4.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.06-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.06-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Jun 17 2022 cunshunxia <cunshunxia@tencent.com> - 4.06-1
- initial build
